Certificados | OiRA
Description: Em função da abordagem adotada pelo parceiro nacional OiRA/programador da ferramenta OiRA, poderá ser possível obter um certificado para a sua avaliação de risco. Para mais informações sobre as vantagens oferecidas por estes certificados, contacte o seu parceiro nacional OiRA.

Temas

# Certificados

Em função da abordagem adotada pelo parceiro nacional OiRA/programador da ferramenta OiRA, poderá ser possível obter um certificado para a sua avaliação de risco. Para mais informações sobre as vantagens oferecidas por estes certificados, contacte o seu parceiro nacional OiRA.

Como obter um certificado

## Realizar uma avaliação de riscos completa

À medida que for elaborando a sua avaliação de riscos, OiRA irá registar o seu progresso. Quando já tiver avaliado um determinado número de riscos, a ferramenta irá informá-lo sobre a possibilidade de obter um certificado após a conclusão da avaliação de riscos completa. Cada parceiro nacional OiRA/programador da ferramenta OiRA define o limiar (percentagens) a partir do qual uma avaliação de risco é considerada «completa». O certificado pode ser obtido através do botão «Estado» no menu situado no lado esquerdo do ecrã.

A página de estado fornece indicação quando um certificado está disponível.

## Ver e emitir o seu certificado

Quando clicar no botão «Ver certificado», ser-lhe-á pedido para inserir o nome da empresa que irá constar do certificado. Dependendo das configurações nacionais da ferramenta, poderá ser-lhe pedido para inserir outros dados, a fim de garantir que o certificado contém todas as informações necessárias.

Introduzir todas as informações necessárias para o certificado.

Se assinalar a caixa «Tornar público», surgirá uma hiperligação (URL) exclusiva para o seu certificado. Copie esta hiperligação e partilhe-a com as pessoas relevantes para comprovar que realizou a sua avaliação de riscos.

Nota: Apenas os dados apresentados nessa página serão tornados públicos. Esta hiperligação não está disponível através do menu do sítio Web de OiRA — só está acessível para si. No entanto, teoricamente, qualquer pessoa com acesso à Internet poderá visualizar o certificado criado por si!

O certificado indica apenas que deu resposta a um determinado número de riscos através da ferramenta de avaliação de riscos, mas não fornece mais informações. As respostas específicas fornecidas na avaliação de riscos efetuada através da ferramenta OiRA só podem ser visualizadas por si.

Scroll to top Load toolbar…
Back

## 5-certificates.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More